@@ -46,9 +46,10 @@ def get_qlbond(bond_info: FixedRateBond, setting: BondSetting,
 def calc_fixbond_structures(value_date: str, bond_info: FixedRateBond, setting: BondSetting,
                 calendar):
     #create Schedule
+    ql_period = ql.Period(ql_freq_tenor[setting.frequency])
     schedule = ql.Schedule(datestr_to_qldate(bond_info.issue_date), 
                             datestr_to_qldate(bond_info.maturity), 
-                            ql_freq_tenor[setting.frequency], 
+                            ql_period, 
                             calendar, 
                             ql_business_day[setting.business_day],
                             ql_business_day[setting.terminate_business_day],
@@ -57,7 +58,7 @@ def calc_fixbond_structures(value_date: str, bond_info: FixedRateBond, setting:
 
     # a sequence of QuantLib.QuantLib.SimpleCashFlow
     interests = ql.FixedRateLeg(schedule, 
-                            ql_day_count[setting.day_count]
+                            ql_day_count[setting.day_count],
                             [bond_info.face_value], 
                             [bond_info.coupon])
     no_of_interests = len(interests)
